@@ -31,6 +31,7 @@
     ])
     .constant('horizon.dashboard.container.containers.events', events())
     .constant('horizon.dashboard.container.containers.validStates', validStates())
+    .constant('horizon.dashboard.container.containers.adminActions', adminActions())
     .constant('horizon.dashboard.container.containers.resourceType', 'OS::Zun::Container')
     .run(run)
     .config(config);
@@ -52,26 +53,41 @@
     var states = {
       ERROR: 'Error', RUNNING: 'Running', STOPPED: 'Stopped',
       PAUSED: 'Paused', UNKNOWN: 'Unknown', CREATING: 'Creating',
-      CREATED: 'Created', DELETED: 'Deleted'
+      CREATED: 'Created', DELETED: 'Deleted', DELETING: 'Deleting',
+      REBUILDING: 'Rebuilding', DEAD: 'Dead', RESTARTING: 'Restarting'
     };
     return {
       update: [states.CREATED, states.RUNNING, states.STOPPED, states.PAUSED],
       start: [states.CREATED, states.STOPPED, states.ERROR],
       stop: [states.RUNNING],
       restart: [states.CREATED, states.RUNNING, states.STOPPED, states.ERROR],
+      rebuild: [states.CREATED, states.RUNNING, states.STOPPED, states.ERROR],
       pause: [states.RUNNING],
       unpause: [states.PAUSED],
       execute: [states.RUNNING],
       kill: [states.RUNNING],
-      delete: [states.CREATED, states.ERROR, states.STOPPED, states.DELETED],
+      delete: [states.CREATED, states.ERROR, states.STOPPED, states.DELETED, states.DEAD],
+      /* NOTE(shu-mutow): Docker does not allow us to delete PAUSED container.
+       *                  There are ways to delete paused container in server,
+       *                  but we are according to Docker's policy as now.
+       */
       delete_force: [
         states.CREATED, states.CREATING, states.ERROR, states.RUNNING,
-        states.STOPPED, states.UNKNOWN, states.DELETED
+        states.STOPPED, states.UNKNOWN, states.DELETED, states.DEAD,
+        states.RESTARTING, states.REBUILDING
       ],
-      delete_stop: [states.RUNNING]
+      delete_stop: [
+        states.RUNNING, states.CREATED, states.ERROR, states.STOPPED,
+        states.DELETED, states.DEAD
+      ],
+      manage_security_groups: [states.CREATED, states.RUNNING, states.STOPPED, states.PAUSED]
     };
   }
 
+  function adminActions() {
+    return ["update", "start", "stop", "restart", "rebuild", "kill", "delete_force"];
+  }
+
   run.$inject = [
     'horizon.framework.conf.resource-type-registry.service',
     'horizon.app.core.openstack-service-api.zun',
@@ -83,9 +99,8 @@
   function run(registry, zun, basePath, resourceType, containerService) {
     registry.getResourceType(resourceType)
     .setNames(gettext('Container'), gettext('Containers'))
-    // for detail summary view on table row.
     .setSummaryTemplateUrl(basePath + 'details/drawer.html')
-    // for table row items and detail summary view.
+    .setDefaultIndexUrl(containerService.getDefaultIndexUrl())
     .setProperties(containerProperties())
     .setListFunction(containerService.getContainersPromise)
     .tableColumns
@@ -144,9 +159,11 @@
   function containerProperties() {
     return {
       'addresses': { label: gettext('Addresses'), filters: ['noValue', 'json'] },
+      'auto_heal': { label: gettext('Auto Heal'), filters: ['yesno'] },
       'auto_remove': { label: gettext('Auto Remove'), filters: ['yesno'] },
       'command': { label: gettext('Command'), filters: ['noValue'] },
       'cpu': { label: gettext('CPU'), filters: ['noValue'] },
+      'disk': { label: gettext('Disk'), filters: ['gb', 'noValue'] },
       'environment': { label: gettext('Environment'), filters: ['noValue', 'json'] },
       'host': { label: gettext('Host'), filters: ['noValue'] },
       'hostname': { label: gettext('Hostname'), filters: ['noValue'] },
@@ -188,8 +205,12 @@
   function config($provide, $windowProvider, $routeProvider) {
     var path = $windowProvider.$get().STATIC_URL + 'dashboard/container/containers/';
     $provide.constant('horizon.dashboard.container.containers.basePath', path);
-    $routeProvider.when('/project/container/containers', {
-      templateUrl: path + 'panel.html'
-    });
+    $routeProvider
+      .when('/project/container/containers', {
+        templateUrl: path + 'panel.html'
+      })
+      .when('/admin/container/containers', {
+        templateUrl: path + 'panel.html'
+      });
   }
 })();
